package com.pm.device.mapper;

import java.util.List;
import com.pm.common.config.PageData;

/**
 * 设备基础信息Mapper接口
 *
 * @author lxf
 * @date 2025-04-29
 */
public interface IbmsDeviceMapper
{
    /**
     * 查询设备基础信息
     *
     * @param id 设备基础信息主键
     * @return 设备基础信息
     */
    public PageData selectIbmsDeviceById(Long id);

    /**
     * 查询设备基础信息列表
     *
     * @param pd
     * @return 设备基础信息集合
     */
    public List<PageData> selectIbmsDeviceList(PageData pd);

    /**
     * 新增设备基础信息
     *
     * @param pd
     * @return 结果
     */
    public int insertIbmsDevice(PageData pd);

    /**
     * 修改设备基础信息
     *
     * @param pd
     * @return 结果
     */
    public int updateIbmsDevice(PageData pd);

    /**
     * 删除设备基础信息
     *
     * @param id 设备基础信息主键
     * @return 结果
     */
    public int deleteIbmsDeviceById(Long id);

    /**
     * 批量删除设备基础信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIbmsDeviceByIds(Long[] ids);
}
